# wxviews

[pyviews](https://github.com/eumis/pyviews) adapter for wxpython. It allows to create ui widgets using xml with binding.

[![Build Status](https://travis-ci.com/eumis/wxviews.svg?branch=dev)](https://travis-ci.com/eumis/wxviews)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/0298085f56ac4dee99817a67f793d6f6)](https://www.codacy.com/app/eumis/wxviews?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=eumis/wxviews&amp;utm_campaign=Badge_Grade)
[![image](https://img.shields.io/pypi/v/wxviews.svg)](https://python.org/pypi/wxviews)
[![image](https://img.shields.io/pypi/pyversions/wxviews.svg)](https://python.org/pypi/wxviews)
[![image](https://img.shields.io/pypi/l/wxviews.svg)](https://python.org/pypi/wxviews)

## Installation

To install dev version:

`pip install git+https://github.com/eumis/wxviews.git@dev`

## Sandbox application

To get started using pyviews see sandbox app.

Clone repository to folder(\[project_root\])

Run following command to install pyviews package

`pip install [project_root] -e`

To run sandbox app execute following commands

```cmd
cd [project_root]\sandbox
python run.py
```

## License

[MIT](http://opensource.org/licenses/MIT)

Copyright (c) 2017-present, eumis (Eugen Misievich)